==================================
Welcome to BOUT++'s documentation!
==================================

The documentation is divided into the following sections:

* User documentation

  * :ref:`getting-started`

  * :ref:`bout-models`

  * :ref:`model-inputs`

  * :ref:`model-outputs`

  * :ref:`bout-interfaces`
  
* :ref:`developer-docs`

     
.. toctree::
   :maxdepth: 2
   :caption: Getting started
   :name: getting-started

   user_docs/introduction
   user_docs/quickstart
   user_docs/installing
   user_docs/advanced_install
   user_docs/running_bout
   user_docs/new_in_v5
   
.. toctree::
   :maxdepth: 2
   :caption: BOUT++ models
   :name: bout-models
      
   user_docs/physics_models
   user_docs/makefiles
   user_docs/variable_init
   user_docs/boundary_options
   user_docs/testing
   user_docs/gpu_support
   user_docs/adios2
   
.. toctree::
   :maxdepth: 2
   :caption: Model inputs
   :name: model-inputs
   
   user_docs/bout_options
   user_docs/input_grids

.. toctree::
   :maxdepth: 2
   :caption: Model outputs
   :name: model-outputs
   
   user_docs/output_and_post
   user_docs/python_boutpp
   
.. toctree::
   :maxdepth: 2
   :caption: BOUT++ interfaces
   :name: bout-interfaces
   
   user_docs/time_integration
   user_docs/parallel-transforms
   user_docs/laplacian
   user_docs/differential_operators
   user_docs/algebraic_operators
   user_docs/staggered_grids
   user_docs/eigenvalue_solver
   user_docs/nonlocal
   user_docs/invertable_operator
   user_docs/petsc

.. toctree::
   :maxdepth: 1
   :caption: Field-aligned coordinate systems
   :name: coordinates

   user_docs/coordinates
   user_docs/preconditioning
   user_docs/BOUT_Gradperp_op

.. toctree::
   :maxdepth: 1
   :caption: Developer Documentation
   :name: developer-docs

   developer_docs/contributing
   developer_docs/git_basics
   developer_docs/code_layout
   developer_docs/data_types
   developer_docs/petsc_interface
   developer_docs/mesh
   developer_docs/file_io
   developer_docs/debugging
   developer_docs/natural_language
   developer_docs/performance_profiling

   api_reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
